@@ -1,10 +1,16 @@
 import importlib
 
+from ocp_resources.pod import Pod
+
 from ocp_utilities.data_collector import (
     get_data_collector_base_dir,
     get_data_collector_dict,
 )
-from ocp_utilities.exceptions import NodeNotReadyError, NodeUnschedulableError
+from ocp_utilities.exceptions import (
+    NodeNotReadyError,
+    NodeUnschedulableError,
+    PodsFailedOrPendingError,
+)
 from ocp_utilities.logger import get_logger
 
 
@@ -49,6 +55,32 @@ def assert_nodes_schedulable(nodes):
         )
 
 
+def assert_pods_failed_or_pending(pods: list[Pod]) -> None:
+    """
+    Validates all pods are not in failed nor pending phase
+
+    Args:
+         pods: List of pod objects
+
+    Raises:
+        PodsFailedOrPendingError: if there are failed or pending pods
+    """
+    LOGGER.info("Verify all pods are not failed nor pending.")
+
+    failed_or_pending_pods = []
+    for pod in pods:
+        if pod.exists:
+            pod_status = pod.instance.status.phase
+            if pod_status in [pod.Status.PENDING, pod.Status.FAILED]:
+                failed_or_pending_pods.append((pod.name, pod_status))
+
+    if failed_or_pending_pods:
+        failed_or_pending_pods_str = "\n\t".join(map(str, failed_or_pending_pods))
+        raise PodsFailedOrPendingError(
+            f"The following pods are failed or pending:\n\t{failed_or_pending_pods_str}",
+        )
+
+
 class DynamicClassCreator:
     """
     Taken from https://stackoverflow.com/a/66815839
